@@ -82,18 +82,20 @@ ostream &operator<<(ostream &stream, Lnb &lnb) {
 	if (lnb.name[0]) 
 	        stream << " NAME \"" << lnb.name << "\""; 
 	stream << " TYPE " << dec << lnb.type << " "; 
-	if (lnb.lof1)
-       	        stream << " LOF1 " << dec << lnb.lof1; 
-	if (lnb.lof2)
-	        stream << " LOF2 " << dec << lnb.lof2; 
-	if (lnb.slof)
-	        stream << " SLOF " << dec << lnb.slof; 
-	if (lnb.diseqcnr!=-1)
-	        stream << " DISEQCNR " << dec << lnb.diseqcnr; 
-	if (lnb.diseqcid!=NOID)
-	        stream << " DISEQCID " << hex << lnb.diseqcid; 
-	if (lnb.swiid!=NOID)
-	        stream << " SWITCHID " << hex << lnb.swiid; 
+	if (lnb.type == FE_QPSK){
+		if (lnb.lof1)
+			stream << " LOF1 " << dec << lnb.lof1; 
+		if (lnb.lof2)
+			stream << " LOF2 " << dec << lnb.lof2; 
+		if (lnb.slof)
+			stream << " SLOF " << dec << lnb.slof; 
+		if (lnb.diseqcnr!=-1)
+			stream << " DISEQCNR " << dec << lnb.diseqcnr; 
+		if (lnb.diseqcid!=NOID)
+			stream << " DISEQCID " << hex << lnb.diseqcid; 
+		if (lnb.swiid!=NOID)
+			stream << " SWITCHID " << hex << lnb.swiid; 
+	}
 	stream << "\n";
 	return stream;
 };
@@ -207,6 +209,7 @@ istream &operator>>(istream &ins, Sat &x){
     
   while(!ins.eof()) {
     streampos pos = ins.tellg();
+    ins.width(MAXNAM);
     ins >> keybuf;
     n=findkey(keybuf, satkeys);
     if (n<0) {
@@ -248,8 +251,8 @@ istream &operator>>(istream &ins, Lnb &x){
 
   while(!ins.eof()) {
     streampos pos = ins.tellg();
+    ins.width(MAXNAM);
     ins >> keybuf;
-    
     n=findkey(keybuf, lnbkeys);
     
     if (n<0) {
@@ -295,11 +298,12 @@ istream &operator>>(istream &ins, Lnb &x){
 istream &operator>>(istream &ins, Transponder &x){
   int n;
   char keybuf[MAXNAM];
-
+  
   x.fec = (int) FEC_AUTO;
   x.inversion = INVERSION_OFF;
   while(!ins.eof()) {
 	  streampos pos = ins.tellg();
+	  ins.width(MAXNAM);
 	  ins >> keybuf;
 	  n=findkey(keybuf, tpkeys);
 	  if (n<0) {
@@ -324,6 +328,7 @@ istream &operator>>(istream &ins, Transponder &x){
 		  break;
 	  case TPOL:
 	  {
+		  ins.width(MAXNAM);
 		  ins >> keybuf;
 		  if (keybuf[0]=='H') {
 			  x.pol=1;
@@ -349,6 +354,7 @@ istream &operator>>(istream &ins, Transponder &x){
 		  ins >> hex >> x.onid;
 		  break;
 	  case TFEC:
+		  ins.width(MAXNAM);
 		  ins >> keybuf;
 		  x.fec = findkey(keybuf, feckeys);
 		  if (x.fec > int(FEC_AUTO) )
@@ -364,6 +370,7 @@ istream &operator>>(istream &ins, Transponder &x){
 		  if (!x.type) x.type = FE_OFDM;
 		  break;
 	  case THP_RATE: 
+		  ins.width(MAXNAM);
 		  ins >> keybuf;
 		  x.hp_rate = findkey(keybuf, feckeys);
 		  if (x.hp_rate > int(FEC_AUTO) )
@@ -372,6 +379,7 @@ istream &operator>>(istream &ins, Transponder &x){
 	                  x.hp_rate = FEC_AUTO;
 		  break;
 	  case TLP_RATE: 
+		  ins.width(MAXNAM);
 		  ins >> keybuf;
 		  x.lp_rate = findkey(keybuf, feckeys);
 		  if (x.lp_rate > int(FEC_AUTO) )
@@ -394,6 +402,7 @@ istream &operator>>(istream &ins, Transponder &x){
 
 	  case TINVERSION: {
 		  int inv;
+		  ins.width(MAXNAM);
 		  ins >> keybuf;
 		  inv = findkey(keybuf, invkeys);
 		  x.inversion = invset[inv]; 
@@ -401,7 +410,6 @@ istream &operator>>(istream &ins, Transponder &x){
 	  }
 	  } 
   }
-  
   if (x.id==NOID || x.freq==0 ){
 	  cerr << "Error: Not enough information for TRANSPONDER" << endl;
 	  exit(1);
@@ -413,9 +421,10 @@ istream &operator>>(istream &ins, Transponder &x){
 istream &operator>>(istream &ins, Channel &x){
   int n;
   char keybuf[MAXNAM];
-
+  
   while(!ins.eof()) {
     streampos pos = ins.tellg();
+    ins.width(MAXNAM);
     ins >> keybuf;
 
     n=findkey(keybuf, chkeys);
