@@ -1205,6 +1205,11 @@ void ts_to_pes( int fdin, uint16_t pida, uint16_t pidv, int ps)
 					  pida,pida);
                 } 
 
+		if (!pida || !pidv){
+			fprintf(stderr,"Can't find PIDs\n");
+			return;
+
+		}
 
 		for( i = 0; i < count; i+= TS_SIZE){
 			uint8_t off = 0;
@@ -2026,7 +2031,9 @@ void send_ipack(ipack *p)
 
 		off = 9+p->buf[8];
 		streamid = p->buf[off];
-		if ((streamid & 0xF8) == 0x80){
+		switch (streamid & 0xF8){
+
+		case 0x80:
 			ai.off = 0;
 			ac3_off = ((p->buf[off+2] << 8)| p->buf[off+3]);
 			if (ac3_off < p->count)
@@ -2041,7 +2048,13 @@ void send_ipack(ipack *p)
 				
 				ac3_off +=  nframes * ai.framesize - p->count;
 			}
+			break;
+
+		case 0x20:
+		default:
+			break;
 		}
+		
 	} 
 	
 	if (p->ps) ps_pes(p);
@@ -2055,15 +2068,27 @@ void send_ipack(ipack *p)
 		p->buf[8] = 0x00;
 		p->count = 9;
 
-		if (p->cid == PRIVATE_STREAM1 && (streamid & 0xF8)==0x80 ){
-			p->count += 4;
-			p->buf[9] = streamid;
-			p->buf[10] = 0;
-			p->buf[11] = (ac3_off >> 8)& 0xFF;
-			p->buf[12] = (ac3_off)& 0xFF;
-		}
-		
+		if (p->cid == PRIVATE_STREAM1){
+
+			switch (streamid & 0xF8){
+
+			case 0x80: 
+				p->count += 4;
+				p->buf[9] = streamid;
+				p->buf[10] = 0;
+				p->buf[11] = (ac3_off >> 8)& 0xFF;
+				p->buf[12] = (ac3_off)& 0xFF;
+				break;
+				
+			case 0x20:
+				p->count += 2;
+				p->buf[9] = 0x20;
+				p->buf[10] = 0;				
+				break;
+			}
+		}		
 		break;
+
 	case 1:
 		p->buf[6] = 0x0F;
 		p->count = 7;
@@ -2095,9 +2120,15 @@ static void write_ipack(ipack *p, uint8_t *data, int count)
 	}
 
 	if (p->cid == PRIVATE_STREAM1 && p->count == p->hlength+9){
-		if ((data[0] & 0xF8) != 0x80){
-			int ac3_off;
+		switch ((data[0] & 0xF8)){
+		case 0x80:
+		case 0x20:
+			break;
 
+		default:
+		{
+			int ac3_off;
+			
 			ac3_off = get_ac3info(data, count, &ai,0);
 			if (ac3_off>=0 && ai.framesize){
 				p->buf[p->count] = 0x80;
@@ -2110,6 +2141,8 @@ static void write_ipack(ipack *p, uint8_t *data, int count)
 				
 			}
 		}
+		break;
+		}
 	}
 
 	if (p->count + count < p->size){
@@ -2122,7 +2155,7 @@ static void write_ipack(ipack *p, uint8_t *data, int count)
 		p->count += rest;
 //		fprintf(stderr,"count: %d \n",p->count);
 		send_ipack(p);
-		if (count - rest > 0)
+		if (rest > 0 && count - rest > 0)
 			write_ipack(p, data+rest, count-rest);
 	}
 }
