@@ -20,6 +20,7 @@ using namespace std;
 #include "cam_menu.hh"
 
 #define CA_DEV    "/dev/dvb/adapter%d/ca%d"
+#define DEMUX_DEV "/dev/dvb/adapter%d/demux%d"
 
 #define MENUTIMEOUT 10
 
@@ -98,6 +99,7 @@ int main(int argc, char **argv)
 	uint16_t apid2=0;
 	uint16_t dpid1=0;
 	uint16_t sid=0;
+	uint16_t set_sid=0;
 	uint16_t current_vpid=0;
 	uint16_t current_apid1=0;
 	uint16_t current_apid2=0;
@@ -122,6 +124,8 @@ int main(int argc, char **argv)
 	int EnLength = 0;
 	char *input = NULL;
 	int menu_sock = MENU_SOCK;
+	int simple_ci = 0;
+	ca_slot_info_t sinfo;
 
 
 	for (;;) {
@@ -165,7 +169,6 @@ int main(int argc, char **argv)
 	}
 	int cams=0;
 	for (uint32_t i=0; i<caps.slot_num; i++){
-		ca_slot_info_t sinfo;
 	
 		sinfo.num = i;
 		if (ioctl(cafd, CA_GET_SLOT_INFO, &sinfo) <0){
@@ -174,23 +177,37 @@ int main(int argc, char **argv)
 		}
 		if (sinfo.flags & CA_CI_MODULE_PRESENT) cams++;
 	}
-	if (!cams){
+
+	if (sinfo.type == CA_CI ){
+		cerr << "CI interface is high level only" << endl;
+		simple_ci = 1;
+		ci_reset(cafd,0);
+	}
+
+	if (!simple_ci && !cams){
 		cerr << "No CAMs present" << endl;
 		exit(1);
 	}
-	cerr << "Found " << cams << "CAM(s)" << endl;
-	close(cafd);
-	
-	ciHandler = cCiHandler::CreateCiHandler(devname);
-	if(!ciHandler) {
-		cout << "No DVB card found" << endl;
-		exit(0);
+	if (!simple_ci){
+		cerr << "Found " << cams << "CAM(s)" << endl;
+		close(cafd);
+	}
+
+	if (!simple_ci){
+		ciHandler = cCiHandler::CreateCiHandler(devname);
+		if(!ciHandler) {
+			cout << "No DVB card found" << endl;
+			exit(0);
+		}
 	}
 
 	cout << "Using /dev/dvb/adapter" << adapter << "/ca" << minor << endl;
-	cout << "Found "<< ciHandler->NumSlots() << " slots" << endl;
+	
+
+	int numslot= sinfo.num;
+	if (simple_ci) numslot=1;
+	cout << "Found "<< numslot << " slots" << endl;
 
-	int numslot=ciHandler->NumSlots();
 	uint8_t cam_buf[BLEN*numslot];
 	int cam_length[numslot];
 	int enread = 0;
@@ -364,23 +381,26 @@ int main(int argc, char **argv)
 					const unsigned short *caids;
 
 					cerr << "Slot " << Slot << endl;
-					caids = ciHandler->GetCaSystemIds(Slot);
-					if (!caids) continue;
-					do {
-						cerr << "checking " << *caids << endl;
-						if ( sysid == *caids) {
-							int l = length + cam_length[Slot];
-							if (l <= BLEN) {
-								memcpy(cam_buf+ Slot*BLEN + 
-								       cam_length[Slot], 
-								       buffer+12, length);
-								cam_length[Slot] += length;
-							}
-							done=1;
-						} else caids++;
-						count++;
-					} while (!done && *caids && count<MAXCASYSTEMIDS);
-				}	
+					if (!simple_ci){
+						caids = ciHandler->GetCaSystemIds(Slot);
+
+						if (!caids) continue;
+						do {
+							cerr << "checking " << *caids << endl;
+							if ( sysid == *caids) {
+								int l = length + cam_length[Slot];
+								if (l <= BLEN) {
+									memcpy(cam_buf+ Slot*BLEN + 
+									       cam_length[Slot], 
+									       buffer+12, length);
+									cam_length[Slot] += length;
+								}
+								done=1;
+							} else caids++;
+							count++;
+						} while (!done && *caids && count<MAXCASYSTEMIDS);
+					} 
+				}
 			}
 		}
 
@@ -393,22 +413,27 @@ int main(int argc, char **argv)
 				cerr << "CAM MENU: error, closing connection" << endl;
 				mtime = time(0)+MENUTIMEOUT;
 				menustate = MENU_NONE;
-				if(ciMenu) ciMenu->Cancel();
+				if (!simple_ci && ciMenu) ciMenu->Cancel();
+				if (simple_ci) ci_cancel_menu(cafd,0);
 				continue;
 			}
 			
 
-			if (cp.type() == CAM_RESET && ciHandler && ciHandler->Reset(0)){
-				close(conn2);
-				conn2=-1;
-				close(conn1);
-				conn1=-1;
-				
-				cerr << "Resetting CAM" << endl;
-				mtime = 0;
-				menustate = MENU_NONE;
-				state = SEARCH;
-				continue;
+			if (cp.type() == CAM_RESET){
+				if ( (!simple_ci && ciHandler && 
+				      ciHandler->Reset(0)) || 
+				     (simple_ci && !ci_reset(cafd,0))){
+					close(conn2);
+					conn2=-1;
+					close(conn1);
+					conn1=-1;
+					
+					cerr << "Resetting CAM" << endl;
+					mtime = 0;
+					menustate = MENU_NONE;
+					state = SEARCH;
+					continue;
+				}
 			}
 				
 			if (cp.type() == CMENU_CLOSE){
@@ -417,7 +442,8 @@ int main(int argc, char **argv)
 				cerr << "Closing Menu Connection" << endl;
 				mtime = time(0)+MENUTIMEOUT;
 				menustate = MENU_NONE;
-				if(ciMenu) ciMenu->Cancel();
+				if(!simple_ci && ciMenu) ciMenu->Cancel();
+				if (simple_ci) ci_cancel_menu(cafd,0);
 				continue;
 			}
 			
@@ -429,7 +455,9 @@ int main(int argc, char **argv)
 				sl = cp.length();
 				sl -= 48;
 				if (!sl) break;
-				if (sl<= numslot && ciHandler->EnterMenu(sl-1)){
+				if (sl<= numslot && 
+				    ((!simple_ci && ciHandler->EnterMenu(sl-1))||
+				     (simple_ci && !ci_enter_menu(cafd,sl-1)))){
 					cerr << "Enter Menu" << endl;
 					mtime = time(0)+MENUTIMEOUT;
 				} else {
@@ -449,13 +477,21 @@ int main(int argc, char **argv)
 				sl = cp.length();
 
 				sl -= 48;
-				if (ciMenu){ 
+				if (!simple_ci && ciMenu){ 
 					if (ciMenu->Selectable() && sl <= mrange && sl>0){
 						ciMenu->Select((uint8_t)(sl-1));
 					} else {
 						ciMenu->Cancel();
 					}
-				} 
+				} else if (simple_ci){
+					if (sl <= mrange && sl>0){
+						ci_menu_select(cafd,0,(uint8_t)(sl-1));
+					} else {
+						ci_cancel_menu(cafd,0);
+					}
+					
+
+				}
 				mtime = time(0)+MENUTIMEOUT;
 			}
 			break;
@@ -482,7 +518,30 @@ int main(int argc, char **argv)
 			}
 		}
 
-		if (ciHandler) {
+		if (simple_ci){
+
+			if(state==CAM){
+				char devname[80];
+				sprintf(devname,DEMUX_DEV,adapter,minor);
+				int fd = open(devname, O_RDWR);
+				set_sid = current_sid;
+				ci_enable_pnr(fd, cafd, 0, current_sid); 
+				close(fd);
+				state = NONE;
+			}
+
+			uint8_t buf[256];
+			if (ci_getmsg(cafd, 0, buf)>=0){
+				CamPacket cp;
+				mtime = 0;
+				if (strlen((char *)buf)>1)
+					fprintf(stderr,"%s\n",(char *)buf);
+				
+			}
+
+		}
+
+		if (!simple_ci && ciHandler) {
 			if (mtime && mtime < time(0)){
 				mtime = 0;
 				menustate = MENU_NONE;
