@@ -6,6 +6,8 @@
 #include <sys/stat.h>
 #include <sys/uio.h>
 #include <netdb.h>
+#include <sys/times.h>
+
 
 #include <ctools.h>
 #define FILELEN 80
@@ -57,7 +59,8 @@ void help(){
 	     << "-i <sid>    service pid"<< endl
 	     << "-t <apid>   audio pid"<< endl
 	     << "-y <inv>    inversion (0=OFF(DEFAULT),1=ON,2=AUTO)"
-	     << "-x <dis>    diseqc"<< endl;
+	     << "-x <dis>    diseqc"<< endl
+	     << "-z          show switch time" << endl;
 }
 
 #define IN_SIZE TS_SIZE*10
@@ -69,6 +72,9 @@ int main(int argc, char **argv)
         uint8_t mbuf[TS_SIZE];
 	int cnum=-1;
 	int c,count ;
+	int show_time=0;
+	clock_t clock1, clock2;
+	struct tms ts1,ts2;
 	Channel *chan;
 	char filename[FILELEN];
 	char *sockname=0;
@@ -102,7 +108,7 @@ int main(int argc, char **argv)
 
         for (;;) {
                 if (-1 == (c = getopt(argc, argv, 
-				      "hf:a:du:onc:pv:V:sq:Ql:r:i:t:x:y:")))
+				      "hf:a:du:onc:pv:V:sq:Ql:r:i:t:x:y:z")))
                         break;
                 switch (c) {
 		case 'h':
@@ -168,10 +174,14 @@ int main(int argc, char **argv)
 		case 'y':
 			inv = strtol(optarg,(char **)NULL,0);
 			break;
+		case 'z':
+			show_time=1;
+			break;
 		}
 	}
 
 	DVB dvb(adapter);
+	dvb.set_showtime(show_time);
 	if(vtxdir) {
 		dvb.set_vtxdir(vtxdir);
 		free(vtxdir);
@@ -230,6 +240,7 @@ int main(int argc, char **argv)
 	while(1){
 		if (cnum >=0 && cnum < dvb.num[CHAN]){
 			if (dvr>1) close(fd_dvr);
+			if (show_time) clock1=times(&ts1);
 			if (dvb.SetChannel(cnum,NULL,&apid,&vpid,freq>=0)<0){
 				cerr << "Tuning failed for " 
 				     << dvb.chans[cnum].name
@@ -237,6 +248,13 @@ int main(int argc, char **argv)
 				cnum = -1;
 				continue;
 			}
+			if (show_time){
+				clock2=times(&ts2);
+				cerr << "Switch time = " 
+				     <<	(double)(clock2-clock1)
+					/double(sysconf(_SC_CLK_TCK)) 
+				     << "s" << endl;
+			}
 			if (dvb.chans[cnum].vpid == NOPID){
 				cerr << "MISSING VIDEO PID" << endl;
 			}
